@@ -17,9 +17,11 @@
 
 package org.sejda.sambox.contentstream.operator.color;
 
+import org.sejda.sambox.contentstream.operator.OperatorName;
+
 /**
- * SCN: Sets the colour to use for stroking stroking operations.
- * Supports Pattern, Separation, DeviceN and ICCBased colour spaces.
+ * SCN: Sets the colour to use for stroking stroking operations. Supports Pattern, Separation, DeviceN and ICCBased
+ * colour spaces.
  *
  * @author John Hewson
  */
@@ -28,6 +30,6 @@ public class SetStrokingColorN extends SetStrokingColor
     @Override
     public String getName()
     {
-        return "SCN";
+        return OperatorName.STROKING_COLOR_N;
     }
 }
