@@ -38,5 +38,9 @@ public enum WriteOption
     /**
      * Adds a Flate filter to the streams if not already there
      */
-    COMPRESS_STREAMS;
+    COMPRESS_STREAMS,
+    /**
+     * Does not automatically update metadata modified date and producer when saving
+     */
+    NO_METADATA_PRODUCER_MODIFIED_DATE_UPDATE;
 }
