@@ -17,8 +17,8 @@
 package org.sejda.sambox.pdmodel;
 
 import static java.util.Objects.nonNull;
+import static org.sejda.commons.util.RequireUtils.requireState;
 import static org.sejda.io.CountingWritableByteChannel.from;
-import static org.sejda.util.RequireUtils.requireState;
 
 import java.awt.Color;
 import java.awt.geom.AffineTransform;
@@ -29,7 +29,8 @@ import java.text.NumberFormat;
 import java.util.Locale;
 import java.util.Stack;
 
-import org.sejda.sambox.contentstream.operator.Operator;
+import org.sejda.commons.util.IOUtils;
+import org.sejda.sambox.contentstream.operator.OperatorName;
 import org.sejda.sambox.cos.COSArray;
 import org.sejda.sambox.cos.COSBase;
 import org.sejda.sambox.cos.COSName;
@@ -57,7 +58,6 @@ import org.sejda.sambox.pdmodel.graphics.shading.PDShading;
 import org.sejda.sambox.pdmodel.graphics.state.PDExtendedGraphicsState;
 import org.sejda.sambox.pdmodel.graphics.state.RenderingMode;
 import org.sejda.sambox.util.Matrix;
-import org.sejda.util.IOUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -295,7 +295,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Error: Nested beginText() calls are not allowed.");
         }
-        writeOperator("BT");
+        writeOperator(OperatorName.BEGIN_TEXT);
         inTextMode = true;
     }
 
@@ -312,7 +312,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: You must call beginText() before calling endText.");
         }
-        writeOperator("ET");
+        writeOperator(OperatorName.END_TEXT);
         inTextMode = false;
     }
 
@@ -349,7 +349,7 @@ public final class PDPageContentStream implements Closeable
 
         writeOperand(resources.add(font));
         writeOperand(fontSize);
-        writeOperator("Tf");
+        writeOperator(OperatorName.SET_FONT_AND_SIZE);
     }
 
     /**
@@ -383,7 +383,7 @@ public final class PDPageContentStream implements Closeable
             }
         }
         write("] ");
-        writeOperator("TJ");
+        writeOperator(OperatorName.SHOW_TEXT_ADJUSTED);
     }
 
     /**
@@ -397,7 +397,7 @@ public final class PDPageContentStream implements Closeable
     {
         showTextInternal(text);
         writer.writeSpace();
-        writeOperator("Tj");
+        writeOperator(OperatorName.SHOW_TEXT);
     }
 
     /**
@@ -444,7 +444,7 @@ public final class PDPageContentStream implements Closeable
     public void setLeading(float leading) throws IOException
     {
         writeOperand(leading);
-        writeOperator("TL");
+        writeOperator(OperatorName.SET_TEXT_LEADING);
     }
 
     /**
@@ -458,7 +458,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Must call beginText() before newLine()");
         }
-        writeOperator("T*");
+        writeOperator(OperatorName.NEXT_LINE);
     }
 
     /**
@@ -478,7 +478,7 @@ public final class PDPageContentStream implements Closeable
         }
         writeOperand(tx);
         writeOperand(ty);
-        writeOperator("Td");
+        writeOperator(OperatorName.MOVE_TEXT);
     }
 
     /**
@@ -496,7 +496,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException("Error: must call beginText() before setTextMatrix");
         }
         writeAffineTransform(matrix.createAffineTransform());
-        writeOperator("Tm");
+        writeOperator(OperatorName.SET_MATRIX);
     }
 
     /**
@@ -588,7 +588,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalArgumentException("Unsupported xobject type");
         }
 
-        writeOperator("Do");
+        writeOperator(OperatorName.DRAW_OBJECT);
 
         restoreGraphicsState();
     }
@@ -632,7 +632,7 @@ public final class PDPageContentStream implements Closeable
 
         // create the image dictionary
         StringBuilder sb = new StringBuilder();
-        sb.append("BI");
+        sb.append(OperatorName.BEGIN_INLINE_IMAGE);
 
         sb.append("\n /W ");
         sb.append(inlineImage.getWidth());
@@ -669,10 +669,10 @@ public final class PDPageContentStream implements Closeable
         this.writer.writeEOL();
 
         // binary data
-        writeOperator(Operator.ID_OPERATOR);
+        writeOperator(OperatorName.BEGIN_INLINE_IMAGE_DATA);
         writeBytes(inlineImage.getData());
         this.writer.writeEOL();
-        writeOperator(Operator.EI_OPERATOR);
+        writeOperator(OperatorName.END_INLINE_IMAGE);
 
         restoreGraphicsState();
     }
@@ -692,7 +692,7 @@ public final class PDPageContentStream implements Closeable
         }
 
         writeOperand(resources.add(form));
-        writeOperator("Do");
+        writeOperator(OperatorName.DRAW_OBJECT);
     }
 
     /**
@@ -709,7 +709,7 @@ public final class PDPageContentStream implements Closeable
                     "Modifying the current transformation matrix is not allowed within text objects.");
         }
         writeAffineTransform(matrix.createAffineTransform());
-        writeOperator("cm");
+        writeOperator(OperatorName.CONCAT);
     }
 
     /**
@@ -735,7 +735,7 @@ public final class PDPageContentStream implements Closeable
         {
             nonStrokingColorSpaceStack.push(nonStrokingColorSpaceStack.peek());
         }
-        writeOperator("q");
+        writeOperator(OperatorName.SAVE);
     }
 
     /**
@@ -761,7 +761,7 @@ public final class PDPageContentStream implements Closeable
         {
             nonStrokingColorSpaceStack.pop();
         }
-        writeOperator("Q");
+        writeOperator(OperatorName.RESTORE);
     }
 
     private COSName getName(PDColorSpace colorSpace)
@@ -777,7 +777,7 @@ public final class PDPageContentStream implements Closeable
     public void setTextRenderingMode(RenderingMode renderingMode) throws IOException
     {
         writeOperand(renderingMode.intValue());
-        writeOperator("Tr");
+        writeOperator(OperatorName.SET_TEXT_RENDERINGMODE);
     }
 
     /**
@@ -793,7 +793,7 @@ public final class PDPageContentStream implements Closeable
                         && color.getColorSpace() != null)
         {
             writeOperand(getName(color.getColorSpace()));
-            writeOperator("CS");
+            writeOperator(OperatorName.STROKING_COLORSPACE);
             setStrokingColorSpaceStack(color.getColorSpace());
         }
 
@@ -812,11 +812,11 @@ public final class PDPageContentStream implements Closeable
                 || color.getColorSpace() instanceof PDDeviceN
                 || color.getColorSpace() instanceof PDICCBased)
         {
-            writeOperator("SCN");
+            writeOperator(OperatorName.STROKING_COLOR_N);
         }
         else
         {
-            writeOperator("SC");
+            writeOperator(OperatorName.STROKING_COLOR);
         }
     }
 
@@ -835,7 +835,7 @@ public final class PDPageContentStream implements Closeable
     }
 
     /**
-     * Set the stroking color in the DeviceRGB color space. Range is 0..255.
+     * Set the stroking color in the DeviceRGB color space. Range is 0..1.
      *
      * @param r The red value
      * @param g The green value.
@@ -843,6 +843,31 @@ public final class PDPageContentStream implements Closeable
      * @throws IOException If an IO error occurs while writing to the stream.
      * @throws IllegalArgumentException If the parameters are invalid.
      */
+    public void setStrokingColor(float r, float g, float b) throws IOException
+    {
+        if (isOutsideOneInterval(r) || isOutsideOneInterval(g) || isOutsideOneInterval(b))
+        {
+            throw new IllegalArgumentException("Parameters must be within 0..1, but are "
+                    + String.format("(%.2f,%.2f,%.2f)", r, g, b));
+        }
+        writeOperand(r);
+        writeOperand(g);
+        writeOperand(b);
+        writeOperator(OperatorName.STROKING_COLOR_RGB);
+        setStrokingColorSpaceStack(PDDeviceRGB.INSTANCE);
+    }
+
+    /**
+     * Set the stroking color in the DeviceRGB color space. Range is 0..255.
+     *
+     * @param r The red value
+     * @param g The green value.
+     * @param b The blue value.
+     * @throws IOException If an IO error occurs while writing to the stream.
+     * @throws IllegalArgumentException If the parameters are invalid.
+     * @deprecated use {@link #setStrokingColor(float, float, float) setStrokingColor(r/255f, g/255f, b/255f)}
+     */
+    @Deprecated
     public void setStrokingColor(int r, int g, int b) throws IOException
     {
         if (isOutside255Interval(r) || isOutside255Interval(g) || isOutside255Interval(b))
@@ -850,11 +875,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalArgumentException("Parameters must be within 0..255, but are "
                     + String.format("(%d,%d,%d)", r, g, b));
         }
-        writeOperand(r / 255f);
-        writeOperand(g / 255f);
-        writeOperand(b / 255f);
-        writeOperator("RG");
-        setStrokingColorSpaceStack(PDDeviceRGB.INSTANCE);
+        setStrokingColor(r / 255f, g / 255f, b / 255f);
     }
 
     /**
@@ -879,7 +900,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(m);
         writeOperand(y);
         writeOperand(k);
-        writeOperator("K");
+        writeOperator(OperatorName.STROKING_COLOR_CMYK);
         setStrokingColorSpaceStack(PDDeviceCMYK.INSTANCE);
     }
 
@@ -897,10 +918,28 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalArgumentException("Parameter must be within 0..1, but is " + g);
         }
         writeOperand(g);
-        writeOperator("G");
+        writeOperator(OperatorName.STROKING_COLOR_GRAY);
         setStrokingColorSpaceStack(PDDeviceGray.INSTANCE);
     }
 
+    /**
+     * Set the stroking color in the DeviceGray color space. Range is 0..255.
+     *
+     * @param g The gray value.
+     * @throws IOException If an IO error occurs while writing to the stream.
+     * @throws IllegalArgumentException If the parameter is invalid.
+     * @deprecated Use {@link #setStrokingColor(float) setStrokingColor(g/255f)} instead.
+     */
+    @Deprecated
+    public void setStrokingColor(int g) throws IOException
+    {
+        if (isOutside255Interval(g))
+        {
+            throw new IllegalArgumentException("Parameter must be within 0..255, but is " + g);
+        }
+        setStrokingColor(g / 255f);
+    }
+
     /**
      * Sets the non-stroking color and, if necessary, the non-stroking color space.
      *
@@ -913,7 +952,7 @@ public final class PDPageContentStream implements Closeable
                 || nonStrokingColorSpaceStack.peek() != color.getColorSpace())
         {
             writeOperand(getName(color.getColorSpace()));
-            writeOperator("cs");
+            writeOperator(OperatorName.NON_STROKING_COLORSPACE);
             setNonStrokingColorSpaceStack(color.getColorSpace());
         }
 
@@ -932,11 +971,11 @@ public final class PDPageContentStream implements Closeable
                 || color.getColorSpace() instanceof PDDeviceN
                 || color.getColorSpace() instanceof PDICCBased)
         {
-            writeOperator("scn");
+            writeOperator(OperatorName.NON_STROKING_COLOR_N);
         }
         else
         {
-            writeOperator("sc");
+            writeOperator(OperatorName.NON_STROKING_COLOR);
         }
     }
 
@@ -963,6 +1002,31 @@ public final class PDPageContentStream implements Closeable
      * @throws IOException If an IO error occurs while writing to the stream.
      * @throws IllegalArgumentException If the parameters are invalid.
      */
+    public void setNonStrokingColor(float r, float g, float b) throws IOException
+    {
+        if (isOutsideOneInterval(r) || isOutsideOneInterval(g) || isOutsideOneInterval(b))
+        {
+            throw new IllegalArgumentException("Parameters must be within 0..1, but are "
+                    + String.format("(%.2f,%.2f,%.2f)", r, g, b));
+        }
+        writeOperand(r);
+        writeOperand(g);
+        writeOperand(b);
+        writeOperator(OperatorName.NON_STROKING_RGB);
+        setNonStrokingColorSpaceStack(PDDeviceRGB.INSTANCE);
+    }
+
+    /**
+     * Set the non stroking color in the DeviceRGB color space. Range is 0..255.
+     *
+     * @param r The red value
+     * @param g The green value.
+     * @param b The blue value.
+     * @throws IOException If an IO error occurs while writing to the stream.
+     * @throws IllegalArgumentException If the parameters are invalid.
+     * @deprecated use {@link #setNonStrokingColor(float, float, float) setNonStrokingColor(r/255f, g/255f, b/255f)}
+     */
+    @Deprecated
     public void setNonStrokingColor(int r, int g, int b) throws IOException
     {
         if (isOutside255Interval(r) || isOutside255Interval(g) || isOutside255Interval(b))
@@ -970,11 +1034,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalArgumentException("Parameters must be within 0..255, but are "
                     + String.format("(%d,%d,%d)", r, g, b));
         }
-        writeOperand(r / 255f);
-        writeOperand(g / 255f);
-        writeOperand(b / 255f);
-        writeOperator("rg");
-        setNonStrokingColorSpaceStack(PDDeviceRGB.INSTANCE);
+        setNonStrokingColor(r / 255f, g / 255f, b / 255f);
     }
 
     /**
@@ -1019,7 +1079,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(m);
         writeOperand(y);
         writeOperand(k);
-        writeOperator("k");
+        writeOperator(OperatorName.NON_STROKING_CMYK);
         setNonStrokingColorSpaceStack(PDDeviceCMYK.INSTANCE);
     }
 
@@ -1053,7 +1113,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalArgumentException("Parameter must be within 0..1, but is " + g);
         }
         writeOperand((float) g);
-        writeOperator("g");
+        writeOperator(OperatorName.NON_STROKING_GRAY);
         setNonStrokingColorSpaceStack(PDDeviceGray.INSTANCE);
     }
 
@@ -1077,7 +1137,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(y);
         writeOperand(width);
         writeOperand(height);
-        writeOperator("re");
+        writeOperator(OperatorName.APPEND_RECT);
     }
 
     /**
@@ -1106,7 +1166,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(y2);
         writeOperand(x3);
         writeOperand(y3);
-        writeOperator("c");
+        writeOperator(OperatorName.CURVE_TO);
     }
 
     /**
@@ -1130,7 +1190,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(y2);
         writeOperand(x3);
         writeOperand(y3);
-        writeOperator("v");
+        writeOperator(OperatorName.CURVE_TO_REPLICATE_INITIAL_POINT);
     }
 
     /**
@@ -1154,7 +1214,7 @@ public final class PDPageContentStream implements Closeable
         writeOperand(y1);
         writeOperand(x3);
         writeOperand(y3);
-        writeOperator("y");
+        writeOperator(OperatorName.CURVE_TO_REPLICATE_FINAL_POINT);
     }
 
     /**
@@ -1173,7 +1233,7 @@ public final class PDPageContentStream implements Closeable
         }
         writeOperand(x);
         writeOperand(y);
-        writeOperator("m");
+        writeOperator(OperatorName.MOVE_TO);
     }
 
     /**
@@ -1192,7 +1252,7 @@ public final class PDPageContentStream implements Closeable
         }
         writeOperand(x);
         writeOperand(y);
-        writeOperator("l");
+        writeOperator(OperatorName.LINE_TO);
     }
 
     /**
@@ -1207,7 +1267,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Error: stroke is not allowed within a text block.");
         }
-        writeOperator("S");
+        writeOperator(OperatorName.STROKE_PATH);
     }
 
     /**
@@ -1223,7 +1283,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: closeAndStroke is not allowed within a text block.");
         }
-        writeOperator("s");
+        writeOperator(OperatorName.CLOSE_AND_STROKE);
     }
 
     /**
@@ -1238,7 +1298,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Error: fill is not allowed within a text block.");
         }
-        writeOperator("f");
+        writeOperator(OperatorName.FILL_NON_ZERO);
     }
 
     /**
@@ -1254,7 +1314,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: fillEvenOdd is not allowed within a text block.");
         }
-        writeOperator("f*");
+        writeOperator(OperatorName.FILL_NON_ZERO);
     }
 
     /**
@@ -1290,7 +1350,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: fillAndStrokeEvenOdd is not allowed within a text block.");
         }
-        writeOperator("B*");
+        writeOperator(OperatorName.FILL_NON_ZERO_AND_STROKE);
     }
 
     /**
@@ -1307,7 +1367,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: closeAndFillAndStroke is not allowed within a text block.");
         }
-        writeOperator("b");
+        writeOperator(OperatorName.CLOSE_FILL_NON_ZERO_AND_STROKE);
     }
 
     /**
@@ -1324,7 +1384,7 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: closeAndFillAndStrokeEvenOdd is not allowed within a text block.");
         }
-        writeOperator("b*");
+        writeOperator(OperatorName.CLOSE_FILL_EVEN_ODD_AND_STROKE);
     }
 
     /**
@@ -1343,7 +1403,7 @@ public final class PDPageContentStream implements Closeable
         }
 
         writeOperand(resources.add(shading));
-        writeOperator("sh");
+        writeOperator(OperatorName.SHADING_FILL);
     }
 
     /**
@@ -1358,7 +1418,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Error: closePath is not allowed within a text block.");
         }
-        writeOperator("h");
+        writeOperator(OperatorName.CLOSE_PATH);
     }
 
     /**
@@ -1373,10 +1433,10 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalStateException("Error: clip is not allowed within a text block.");
         }
-        writeOperator("W");
+        writeOperator(OperatorName.CLIP_NON_ZERO);
 
         // end path without filling or stroking
-        writeOperator("n");
+        writeOperator(OperatorName.ENDPATH);
     }
 
     /**
@@ -1392,10 +1452,10 @@ public final class PDPageContentStream implements Closeable
             throw new IllegalStateException(
                     "Error: clipEvenOdd is not allowed within a text block.");
         }
-        writeOperator("W*");
+        writeOperator(OperatorName.CLIP_EVEN_ODD);
 
         // end path without filling or stroking
-        writeOperator("n");
+        writeOperator(OperatorName.ENDPATH);
     }
 
     /**
@@ -1413,7 +1473,7 @@ public final class PDPageContentStream implements Closeable
                     "Error: setLineWidth is not allowed within a text block.");
         }
         writeOperand(lineWidth);
-        writeOperator("w");
+        writeOperator(OperatorName.SET_LINE_WIDTH);
     }
 
     /**
@@ -1434,7 +1494,7 @@ public final class PDPageContentStream implements Closeable
         if (lineJoinStyle >= 0 && lineJoinStyle <= 2)
         {
             writeOperand(lineJoinStyle);
-            writeOperator("j");
+            writeOperator(OperatorName.SET_LINE_JOINSTYLE);
         }
         else
         {
@@ -1460,7 +1520,7 @@ public final class PDPageContentStream implements Closeable
         if (lineCapStyle >= 0 && lineCapStyle <= 2)
         {
             writeOperand(lineCapStyle);
-            writeOperator("J");
+            writeOperator(OperatorName.SET_LINE_CAPSTYLE);
         }
         else
         {
@@ -1490,7 +1550,7 @@ public final class PDPageContentStream implements Closeable
         }
         write("] ");
         writeOperand(phase);
-        writeOperator("d");
+        writeOperator(OperatorName.SET_LINE_DASHPATTERN);
     }
 
     /**
@@ -1505,7 +1565,7 @@ public final class PDPageContentStream implements Closeable
         requireState(miterLimit > 0,
                 "A miter limit <= 0 is invalid and will not render in Acrobat Reader");
         writeOperand(miterLimit);
-        writeOperator("M");
+        writeOperator(OperatorName.SET_LINE_MITERLIMIT);
     }
 
     /**
@@ -1517,7 +1577,7 @@ public final class PDPageContentStream implements Closeable
     public void beginMarkedContent(COSName tag) throws IOException
     {
         writeOperand(tag);
-        writeOperator("BMC");
+        writeOperator(OperatorName.BEGIN_MARKED_CONTENT);
     }
 
     /**
@@ -1531,7 +1591,7 @@ public final class PDPageContentStream implements Closeable
     {
         writeOperand(tag);
         writeOperand(resources.add(propertyList));
-        writeOperator("BDC");
+        writeOperator(OperatorName.BEGIN_MARKED_CONTENT_SEQ);
     }
 
     /**
@@ -1541,7 +1601,7 @@ public final class PDPageContentStream implements Closeable
      */
     public void endMarkedContent() throws IOException
     {
-        writeOperator("EMC");
+        writeOperator(OperatorName.END_MARKED_CONTENT);
     }
 
     /**
@@ -1553,7 +1613,7 @@ public final class PDPageContentStream implements Closeable
     public void setGraphicsStateParameters(PDExtendedGraphicsState state) throws IOException
     {
         writeOperand(resources.add(state));
-        writeOperator("gs");
+        writeOperator(OperatorName.SET_GRAPHICS_STATE_PARAMS);
     }
 
     /**
@@ -1570,9 +1630,7 @@ public final class PDPageContentStream implements Closeable
         {
             throw new IllegalArgumentException("comment should not include a newline");
         }
-        writer.writer().write((byte) '%');
-        write(comment);
-        writer.writeEOL();
+        writer.writeComment(comment);
     }
 
     protected void writeOperand(float real) throws IOException
@@ -1696,7 +1754,7 @@ public final class PDPageContentStream implements Closeable
     public void setRenderingMode(RenderingMode rm) throws IOException
     {
         writeOperand(rm.intValue());
-        writeOperator("Tr");
+        writeOperator(OperatorName.SET_TEXT_RENDERINGMODE);
     }
 
     /**
@@ -1709,7 +1767,7 @@ public final class PDPageContentStream implements Closeable
     public void setCharacterSpacing(float spacing) throws IOException
     {
         writeOperand(spacing);
-        writeOperator("Tc");
+        writeOperator(OperatorName.SET_CHAR_SPACING);
     }
 
     /**
@@ -1722,7 +1780,7 @@ public final class PDPageContentStream implements Closeable
     public void setWordSpacing(float spacing) throws IOException
     {
         writeOperand(spacing);
-        writeOperator("Tw");
+        writeOperator(OperatorName.SET_WORD_SPACING);
     }
 
     /**
@@ -1734,7 +1792,7 @@ public final class PDPageContentStream implements Closeable
     public void setHorizontalScaling(float scale) throws IOException
     {
         writeOperand(scale);
-        writeOperator("Tz");
+        writeOperator(OperatorName.SET_TEXT_HORIZONTAL_SCALING);
     }
 
     /**
@@ -1748,6 +1806,6 @@ public final class PDPageContentStream implements Closeable
     public void setTextRise(float rise) throws IOException
     {
         writeOperand(rise);
-        writeOperator("Ts");
+        writeOperator(OperatorName.SET_TEXT_RISE);
     }
 }
