@@ -18,7 +18,6 @@
 package org.sejda.sambox.pdmodel.encryption;
 
 import java.io.ByteArrayInputStream;
-import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -47,6 +46,8 @@ import org.bouncycastle.crypto.modes.CBCBlockCipher;
 import org.bouncycastle.crypto.paddings.PaddedBufferedBlockCipher;
 import org.bouncycastle.crypto.params.KeyParameter;
 import org.bouncycastle.crypto.params.ParametersWithIV;
+import org.sejda.commons.FastByteArrayOutputStream;
+import org.sejda.commons.util.IOUtils;
 import org.sejda.sambox.cos.COSArray;
 import org.sejda.sambox.cos.COSBase;
 import org.sejda.sambox.cos.COSDictionary;
@@ -54,7 +55,6 @@ import org.sejda.sambox.cos.COSName;
 import org.sejda.sambox.cos.COSStream;
 import org.sejda.sambox.cos.COSString;
 import org.sejda.sambox.pdmodel.PDDocument;
-import org.sejda.util.IOUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -101,6 +101,16 @@ public abstract class SecurityHandler
      */
     private AccessPermission currentAccessPermission = null;
 
+    /**
+     * The stream filter name.
+     */
+    private COSName streamFilterName;
+
+    /**
+     * The string filter name.
+     */
+    private COSName stringFilterName;
+
     /**
      * Set wether to decrypt meta data.
      *
@@ -111,6 +121,26 @@ public abstract class SecurityHandler
         this.decryptMetadata = decryptMetadata;
     }
 
+    /**
+     * Set the string filter name.
+     * 
+     * @param stringFilterName the string filter name.
+     */
+    protected void setStringFilterName(COSName stringFilterName)
+    {
+        this.stringFilterName = stringFilterName;
+    }
+
+    /**
+     * Set the stream filter name.
+     * 
+     * @param streamFilterName the stream filter name.
+     */
+    protected void setStreamFilterName(COSName streamFilterName)
+    {
+        this.streamFilterName = streamFilterName;
+    }
+
     /**
      * Prepares everything to decrypt the document.
      *
@@ -121,7 +151,7 @@ public abstract class SecurityHandler
      * @throws IOException If there is an error accessing data.
      */
     public abstract void prepareForDecryption(PDEncryption encryption, COSArray documentIDArray,
-            DecryptionMaterial decryptionMaterial) throws InvalidPasswordException, IOException;
+            DecryptionMaterial decryptionMaterial) throws IOException;
 
     /**
      * Encrypt or decrypt a set of data.
@@ -304,7 +334,7 @@ public abstract class SecurityHandler
         cipher.init(false, new ParametersWithIV(new KeyParameter(encryptionKey), iv));
         try (CipherInputStream cis = new CipherInputStream(data, cipher))
         {
-            org.apache.commons.io.IOUtils.copy(cis, output);
+            IOUtils.copy(cis, output);
         }
     }
 
@@ -363,37 +393,40 @@ public abstract class SecurityHandler
      */
     public void decryptStream(COSStream stream, long objNum, long genNum) throws IOException
     {
-        COSBase type = stream.getCOSName(COSName.TYPE);
-        if (!decryptMetadata && COSName.METADATA.equals(type))
+        if (!COSName.IDENTITY.equals(streamFilterName))
         {
-            return;
-        }
-        // "The cross-reference stream shall not be encrypted"
-        if (COSName.XREF.equals(type))
-        {
-            return;
-        }
-        if (COSName.METADATA.equals(type))
-        {
-            byte buf[] = new byte[10];
-            // PDFBOX-3229 check case where metadata is not encrypted despite /EncryptMetadata missing
-            try (InputStream is = stream.getUnfilteredStream())
+            COSBase type = stream.getCOSName(COSName.TYPE);
+            if (!decryptMetadata && COSName.METADATA.equals(type))
             {
-                is.read(buf);
-            }
-            if (Arrays.equals(buf, "<?xpacket ".getBytes(StandardCharsets.ISO_8859_1)))
-            {
-                LOG.warn("Metadata is not encrypted, but was expected to be");
-                LOG.warn("Read PDF specification about EncryptMetadata (default value: true)");
                 return;
             }
-        }
-        decryptDictionary(stream, objNum, genNum);
-        byte[] encrypted = IOUtils.toByteArray(stream.getFilteredStream());
-        ByteArrayInputStream encryptedStream = new ByteArrayInputStream(encrypted);
-        try (OutputStream output = stream.createFilteredStream())
-        {
-            decryptData(objNum, genNum, encryptedStream, output);
+            // "The cross-reference stream shall not be encrypted"
+            if (COSName.XREF.equals(type))
+            {
+                return;
+            }
+            if (COSName.METADATA.equals(type))
+            {
+                byte buf[] = new byte[10];
+                // PDFBOX-3229 check case where metadata is not encrypted despite /EncryptMetadata missing
+                try (InputStream is = stream.getUnfilteredStream())
+                {
+                    is.read(buf);
+                }
+                if (Arrays.equals(buf, "<?xpacket ".getBytes(StandardCharsets.ISO_8859_1)))
+                {
+                    LOG.warn("Metadata is not encrypted, but was expected to be");
+                    LOG.warn("Read PDF specification about EncryptMetadata (default value: true)");
+                    return;
+                }
+            }
+            decryptDictionary(stream, objNum, genNum);
+            byte[] encrypted = IOUtils.toByteArray(stream.getFilteredStream());
+            ByteArrayInputStream encryptedStream = new ByteArrayInputStream(encrypted);
+            try (OutputStream output = stream.createFilteredStream())
+            {
+                decryptData(objNum, genNum, encryptedStream, output);
+            }
         }
     }
 
@@ -448,17 +481,20 @@ public abstract class SecurityHandler
      */
     private void decryptString(COSString string, long objNum, long genNum) throws IOException
     {
-        ByteArrayInputStream data = new ByteArrayInputStream(string.getBytes());
-        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
-        try
+        if (!COSName.IDENTITY.equals(stringFilterName))
         {
-            decryptData(objNum, genNum, data, outputStream);
-            string.setValue(outputStream.toByteArray());
-        }
-        catch (IOException ex)
-        {
-            LOG.error("Failed to decrypt COSString of length " + string.getBytes().length
-                    + " in object " + objNum + ": " + ex.getMessage());
+            ByteArrayInputStream data = new ByteArrayInputStream(string.getBytes());
+            FastByteArrayOutputStream outputStream = new FastByteArrayOutputStream();
+            try
+            {
+                decryptData(objNum, genNum, data, outputStream);
+                string.setValue(outputStream.toByteArray());
+            }
+            catch (IOException ex)
+            {
+                LOG.error("Failed to decrypt COSString of length " + string.getBytes().length
+                        + " in object " + objNum + ": " + ex.getMessage());
+            }
         }
     }
 
