@@ -17,6 +17,7 @@
 package org.sejda.sambox.pdmodel.font;
 
 import static java.util.Optional.ofNullable;
+import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -36,6 +37,7 @@ import org.apache.fontbox.ttf.OpenTypeFont;
 import org.apache.fontbox.ttf.TTFParser;
 import org.apache.fontbox.ttf.TrueTypeFont;
 import org.apache.fontbox.type1.Type1Font;
+import org.sejda.sambox.SAMBox;
 
 /**
  * Font mapper, locates non-embedded fonts via a pluggable FontProvider.
@@ -102,14 +104,11 @@ final class FontMapperImpl implements FontMapper
 
         try
         {
-            String ttfName = "/org/sejda/sambox/resources/ttf/LiberationSans-Regular.ttf";
-            InputStream ttfStream = FontMapper.class.getResourceAsStream(ttfName);
-            if (ttfStream == null)
-            {
-                throw new IOException("Error loading resource: " + ttfName);
-            }
-            TTFParser ttfParser = new TTFParser();
-            lastResortFont = ttfParser.parse(ttfStream);
+            InputStream stream = FontMapperImpl.class.getResourceAsStream(
+                    "/org/sejda/sambox/resources/ttf/LiberationSans-Regular.ttf");
+            requireNotNullArg(stream,
+                    "Unable to load org/sejda/sambox/resources/ttf/LiberationSans-Regular.ttf");
+            lastResortFont = new TTFParser().parse(stream);
         }
         catch (IOException e)
         {
@@ -117,10 +116,22 @@ final class FontMapperImpl implements FontMapper
         }
     }
 
+    public TrueTypeFont getLastResortFont() {
+        return lastResortFont;
+    }
+
     // lazy thread safe singleton
     private static class DefaultFontProvider
     {
-        private static final FontProvider INSTANCE = new FileSystemFontProvider(fontCache);
+        private static final FontProvider INSTANCE = initializeFontProvider();
+        
+        private static FontProvider initializeFontProvider() {
+            if("noop".equalsIgnoreCase(System.getProperty(SAMBox.FONT_PROVIDER_PROPERTY))) {
+                return new NoopFontProvider();
+            } else {
+                return new FileSystemFontProvider(fontCache);
+            }
+        }
     }
 
     /**
@@ -170,13 +181,13 @@ final class FontMapperImpl implements FontMapper
      */
     private Set<String> getPostScriptNames(String postScriptName)
     {
-        Set<String> names = new HashSet<String>();
+        Set<String> names = new HashSet<>();
 
         // built-in PostScript name
         names.add(postScriptName);
 
         // remove hyphens (e.g. Arial-Black -> ArialBlack)
-        names.add(postScriptName.replaceAll("-", ""));
+        names.add(postScriptName.replace("-", ""));
 
         return names;
     }
@@ -186,7 +197,7 @@ final class FontMapperImpl implements FontMapper
      */
     private List<String> copySubstitutes(String postScriptName)
     {
-        return new ArrayList<String>(substitutes.get(postScriptName));
+        return new ArrayList<>(substitutes.get(postScriptName));
     }
 
     /**
@@ -209,7 +220,7 @@ final class FontMapperImpl implements FontMapper
      */
     private List<String> getSubstitutes(String postScriptName)
     {
-        List<String> subs = substitutes.get(postScriptName.replaceAll(" ", ""));
+        List<String> subs = substitutes.get(postScriptName.replace(" ", ""));
         if (subs != null)
         {
             return subs;
@@ -309,7 +320,7 @@ final class FontMapperImpl implements FontMapper
         TrueTypeFont ttf = (TrueTypeFont) findFont(FontFormat.TTF, baseFont);
         if (ttf != null)
         {
-            return new FontMapping<TrueTypeFont>(ttf, false);
+            return new FontMapping<>(ttf, false);
         }
         // fallback - todo: i.e. fuzzy match
         String fontName = getFallbackFontName(fontDescriptor);
@@ -319,7 +330,7 @@ final class FontMapperImpl implements FontMapper
             // we have to return something here as TTFs aren't strictly required on the system
             ttf = lastResortFont;
         }
-        return new FontMapping<TrueTypeFont>(ttf, true);
+        return new FontMapping<>(ttf, true);
     }
 
     /**
@@ -334,7 +345,7 @@ final class FontMapperImpl implements FontMapper
         FontBoxFont font = findFontBoxFont(baseFont);
         if (font != null)
         {
-            return new FontMapping<FontBoxFont>(font, false);
+            return new FontMapping<>(font, false);
         }
         // fallback - todo: i.e. fuzzy match
         String fallbackName = getFallbackFontName(fontDescriptor);
@@ -344,7 +355,7 @@ final class FontMapperImpl implements FontMapper
             // we have to return something here as TTFs aren't strictly required on the system
             font = lastResortFont;
         }
-        return new FontMapping<FontBoxFont>(font, true);
+        return new FontMapping<>(font, true);
     }
 
     /**
@@ -402,7 +413,7 @@ final class FontMapperImpl implements FontMapper
         }
 
         // remove hyphens (e.g. Arial-Black -> ArialBlack)
-        info = getFont(format, postScriptName.replaceAll("-", ""));
+        info = getFont(format, postScriptName.replace("-", ""));
         if (info != null)
         {
             return info.getFont();
