@@ -27,11 +27,10 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
-import org.apache.commons.io.IOUtils;
 import org.apache.fontbox.afm.FontMetrics;
 import org.apache.fontbox.cmap.CMap;
-import org.apache.fontbox.util.BoundingBox;
-import org.sejda.io.FastByteArrayOutputStream;
+import org.sejda.commons.FastByteArrayOutputStream;
+import org.sejda.commons.util.IOUtils;
 import org.sejda.sambox.cos.COSArray;
 import org.sejda.sambox.cos.COSArrayList;
 import org.sejda.sambox.cos.COSBase;
@@ -106,46 +105,58 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
 
         // standard 14 fonts use an AFM
         afmStandard14 = Standard14Fonts.getAFM(getName()); // may be null (it usually is)
+        fontDescriptor = loadFontDescriptor();
+        toUnicodeCMap = loadUnicodeCmap();
+    }
 
-        // font descriptor
-        COSDictionary fd = (COSDictionary) dict.getDictionaryObject(COSName.FONT_DESC);
-        if (fd != null)
+    private PDFontDescriptor loadFontDescriptor()
+    {
+        COSDictionary fd = dict.getDictionaryObject(COSName.FONT_DESC, COSDictionary.class);
+        if (nonNull(fd))
         {
-            fontDescriptor = new PDFontDescriptor(fd);
+            return new PDFontDescriptor(fd);
         }
         else if (afmStandard14 != null)
         {
             // build font descriptor from the AFM
-            fontDescriptor = PDType1FontEmbedder.buildFontDescriptor(afmStandard14);
+            return PDType1FontEmbedder.buildFontDescriptor(afmStandard14);
         }
-        else
+        return null;
+    }
+
+    private CMap loadUnicodeCmap()
+    {
+        COSBase toUnicode = dict.getDictionaryObject(COSName.TO_UNICODE);
+        if (toUnicode == null)
         {
-            fontDescriptor = null;
+            return null;
         }
 
-        // ToUnicode CMap
-        COSBase toUnicode = dict.getDictionaryObject(COSName.TO_UNICODE);
-        if (toUnicode != null)
+        CMap cmap = null;
+        try
         {
-            CMap cmap = null;
-            try
+            cmap = readCMap(toUnicode);
+            if (cmap != null && !cmap.hasUnicodeMappings())
             {
-                cmap = readCMap(toUnicode);
-                if (cmap != null && !cmap.hasUnicodeMappings())
+                LOG.warn("Invalid ToUnicode CMap in font " + getName());
+                String cmapName = cmap.getName() != null ? cmap.getName() : "";
+                String ordering = cmap.getOrdering() != null ? cmap.getOrdering() : "";
+                COSBase encoding = dict.getDictionaryObject(COSName.ENCODING);
+                if (cmapName.contains("Identity") //
+                        || ordering.contains("Identity") //
+                        || COSName.IDENTITY_H.equals(encoding) //
+                        || COSName.IDENTITY_V.equals(encoding))
                 {
-                    LOG.warn("Invalid ToUnicode CMap in font " + getName());
+                    // assume that if encoding is identity, then the reverse is also true
+                    cmap = CMapManager.getPredefinedCMap(COSName.IDENTITY_H.getName());
                 }
             }
-            catch (IOException ex)
-            {
-                LOG.error("Could not read ToUnicode CMap in font " + getName(), ex);
-            }
-            toUnicodeCMap = cmap;
         }
-        else
+        catch (IOException ex)
         {
-            toUnicodeCMap = null;
+            LOG.error("Could not read ToUnicode CMap in font " + getName(), ex);
         }
+        return cmap;
     }
 
     /**
@@ -294,15 +305,6 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
      */
     protected abstract float getStandard14Width(int code);
 
-    @Override
-    public abstract float getWidthFromFont(int code) throws IOException;
-
-    @Override
-    public abstract boolean isEmbedded();
-
-    @Override
-    public abstract float getHeight(int code) throws IOException;
-
     /**
      * Encodes the given string for use in a PDF content stream.
      *
@@ -345,7 +347,8 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
             }
             catch (IllegalArgumentException e)
             {
-                if (e.getMessage().contains("No glyph"))
+                if (e.getMessage().contains("No glyph")
+                        || e.getMessage().contains("is not available in this"))
                 {
                     bytes = new byte[] { (byte) codePoint };
                 }
@@ -503,7 +506,7 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
                 // code->Unicode maps. See sample_fonts_solidconvertor.pdf for an example.
                 // PDFBOX-3123: do this only if the /ToUnicode entry is a name
                 // PDFBOX-4322: identity streams are OK too
-                return new String(new char[]{(char) code});
+                return new String(new char[] { (char) code });
             }
             // proceed as normal
             return toUnicodeCMap.toUnicode(code);
@@ -532,12 +535,6 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
         return dict.getNameAsString(COSName.SUBTYPE);
     }
 
-    @Override
-    public abstract String getName();
-
-    @Override
-    public abstract BoundingBox getBoundingBox() throws IOException;
-
     /**
      * The widths of the characters. This will be null for the standard 14 fonts.
      *
@@ -633,9 +630,6 @@ public abstract class PDFont implements COSObjectable, PDFontLike, Subsettable
         return Standard14Fonts.containsName(getName());
     }
 
-    @Override
-    public abstract boolean isDamaged();
-
     @Override
     public boolean equals(Object other)
     {
