@@ -17,6 +17,7 @@
 package org.sejda.sambox.pdmodel.graphics.color;
 
 import static java.util.Objects.nonNull;
+import static org.sejda.commons.util.RequireUtils.requireIOCondition;
 
 import java.awt.color.ColorSpace;
 import java.awt.color.ICC_ColorSpace;
@@ -85,12 +86,9 @@ public class PDDeviceCMYK extends PDDeviceColorSpace
         String name = "/org/sejda/sambox/resources/icc/ISOcoated_v2_300_bas.icc";
         try (InputStream is = PDDeviceCMYK.class.getResourceAsStream(name))
         {
-            if (nonNull(is))
-            {
-                return ICC_Profile.getInstance(is);
-            }
+            requireIOCondition(nonNull(is), "Error loading " + name);
+            return ICC_Profile.getInstance(is);
         }
-        throw new IOException("Error loading resource: " + name);
     }
 
     @Override
