@@ -31,7 +31,7 @@ import java.util.zip.DeflaterOutputStream;
 
 import javax.imageio.stream.MemoryCacheImageOutputStream;
 
-import org.sejda.io.FastByteArrayOutputStream;
+import org.sejda.commons.FastByteArrayOutputStream;
 import org.sejda.sambox.cos.COSDictionary;
 import org.sejda.sambox.cos.COSInteger;
 import org.sejda.sambox.cos.COSName;
@@ -78,13 +78,12 @@ public final class LosslessFactory
      */
     public static PDImageXObject createFromImage(BufferedImage image) throws IOException
     {
-        if ((image.getType() == BufferedImage.TYPE_BYTE_GRAY
-                && image.getColorModel().getPixelSize() <= 8)
-                || (image.getType() == BufferedImage.TYPE_BYTE_BINARY
-                        && image.getColorModel().getPixelSize() == 1))
+        if (isGrayImage(image))
         {
             return createFromGrayImage(image);
         }
+
+        // We try to encode the image with predictor
         if (usePredictorEncoder)
         {
             PDImageXObject pdImageXObject = new PredictorEncoder(image).encode();
@@ -112,6 +111,25 @@ public final class LosslessFactory
         return createFromRGBImage(image);
     }
 
+    private static boolean isGrayImage(BufferedImage image)
+    {
+        if (image.getTransparency() != Transparency.OPAQUE)
+        {
+            return false;
+        }
+        if (image.getType() == BufferedImage.TYPE_BYTE_GRAY
+                && image.getColorModel().getPixelSize() <= 8)
+        {
+            return true;
+        }
+        if (image.getType() == BufferedImage.TYPE_BYTE_BINARY
+                && image.getColorModel().getPixelSize() == 1)
+        {
+            return true;
+        }
+        return false;
+    }
+
     // grayscale images need one color per sample
     private static PDImageXObject createFromGrayImage(BufferedImage image) throws IOException
     {
@@ -225,7 +243,7 @@ public final class LosslessFactory
      * @return the newly created PDImageXObject with the data compressed.
      * @throws IOException
      */
-    private static PDImageXObject prepareImageXObject(byte[] byteArray, int width, int height,
+    static PDImageXObject prepareImageXObject(byte[] byteArray, int width, int height,
             int bitsPerComponent, PDColorSpace initColorSpace) throws IOException
     {
         FastByteArrayOutputStream baos = new FastByteArrayOutputStream();
@@ -551,8 +569,10 @@ public final class LosslessFactory
             int w = image.getWidth();
 
             ColorSpace srcCspace = image.getColorModel().getColorSpace();
-            PDColorSpace pdColorSpace = srcCspace.getType() != ColorSpace.TYPE_CMYK
-                    ? PDDeviceRGB.INSTANCE : PDDeviceCMYK.INSTANCE;
+            int srcCspaceType = srcCspace.getType();
+            PDColorSpace pdColorSpace = srcCspaceType == ColorSpace.TYPE_CMYK
+                    ? PDDeviceCMYK.INSTANCE : (srcCspaceType == ColorSpace.TYPE_GRAY
+                            ? PDDeviceGray.INSTANCE : PDDeviceRGB.INSTANCE);
 
             // Encode the image profile if the image has one
             if (srcCspace instanceof ICC_ColorSpace)
@@ -569,8 +589,9 @@ public final class LosslessFactory
                     pdProfile.getPDStream().getCOSObject().setInt(COSName.N,
                             srcCspace.getNumComponents());
                     pdProfile.getPDStream().getCOSObject().setItem(COSName.ALTERNATE,
-                            srcCspace.getType() == ColorSpace.TYPE_CMYK ? COSName.DEVICECMYK
-                                    : COSName.DEVICERGB);
+                            srcCspaceType == ColorSpace.TYPE_GRAY ? COSName.DEVICEGRAY
+                                    : (srcCspaceType == ColorSpace.TYPE_CMYK ? COSName.DEVICECMYK
+                                            : COSName.DEVICERGB));
                     pdColorSpace = pdProfile;
                 }
             }
