@@ -257,6 +257,13 @@ public class PDFRenderer
         int widthPx = (int) Math.max(Math.floor(widthPt * scale), 1);
         int heightPx = (int) Math.max(Math.floor(heightPt * scale), 1);
 
+        // PDFBOX-4518 the maximum size (w*h) of a buffered image is limited to Integer.MAX_VALUE
+        if ((long) widthPx * (long) heightPx > Integer.MAX_VALUE)
+        {
+            throw new IOException("Maximum size of image exceeded (w * h * scale) = "//
+                    + widthPt + " * " + heightPt + " * " + scale + " > " + Integer.MAX_VALUE);
+        }
+
         int rotationAngle = page.getRotation();
 
         int bimType = imageType.toBufferedImageType();
@@ -365,11 +372,23 @@ public class PDFRenderer
 
     /**
      * Renders a given page to an AWT Graphics2D instance.
+     * <p>
+     * Known problems:
+     * <ul>
+     * <li>rendering of PDF files with transparencies is not supported on Ubuntu, see
+     * <a href="https://issues.apache.org/jira/browse/PDFBOX-4581">PDFBOX-4581</a> and
+     * <a href="https://bugs.openjdk.java.net/browse/JDK-6689349">JDK-6689349</a>. Rendering will not abort, but the
+     * pages will be rendered incorrectly.</li>
+     * <li>Clipping the Graphics2D will not work properly, see
+     * <a href="https://issues.apache.org/jira/browse/PDFBOX-4583">PDFBOX-4583</a>.</li>
+     * </ul>
+     * If you encounter these problems, then you should render into an image by using the {@link #renderImage(int)
+     * renderImage} methods.
      * 
      * @param pageIndex the zero-based index of the page to be converted
      * @param graphics the Graphics2D on which to draw the page
-     * @param scaleX the scale to draw the page at for the x-axis
-     * @param scaleY the scale to draw the page at for the y-axis
+     * @param scaleX the scale to draw the page at for the x-axis, where 1 = 72 DPI
+     * @param scaleY the scale to draw the page at for the y-axis, where 1 = 72 DPI
      * @param destination controlling visibility of optional content groups
      * @throws IOException if the PDF cannot be read
      */
@@ -377,7 +396,7 @@ public class PDFRenderer
             RenderDestination destination) throws IOException
     {
         PDPage page = document.getPage(pageIndex);
-        // TODO need width/wight calculations? should these be in PageDrawer?
+        // TODO need width/height calculations? should these be in PageDrawer?
 
         transform(graphics, page, scaleX, scaleY);
 
