@@ -16,6 +16,8 @@
  */
 package org.sejda.sambox.text;
 
+import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
+
 import java.io.IOException;
 import java.io.InputStream;
 
@@ -23,6 +25,7 @@ import org.apache.fontbox.ttf.TrueTypeFont;
 import org.apache.fontbox.util.BoundingBox;
 import org.sejda.sambox.contentstream.PDFStreamEngine;
 import org.sejda.sambox.contentstream.operator.DrawObject;
+import org.sejda.sambox.contentstream.operator.color.*;
 import org.sejda.sambox.contentstream.operator.state.Concatenate;
 import org.sejda.sambox.contentstream.operator.state.Restore;
 import org.sejda.sambox.contentstream.operator.state.Save;
@@ -55,7 +58,9 @@ import org.sejda.sambox.pdmodel.font.PDTrueTypeFont;
 import org.sejda.sambox.pdmodel.font.PDType0Font;
 import org.sejda.sambox.pdmodel.font.PDType3Font;
 import org.sejda.sambox.pdmodel.font.encoding.GlyphList;
+import org.sejda.sambox.pdmodel.graphics.color.PDColor;
 import org.sejda.sambox.pdmodel.graphics.state.PDGraphicsState;
+import org.sejda.sambox.pdmodel.graphics.state.RenderingMode;
 import org.sejda.sambox.util.Matrix;
 import org.sejda.sambox.util.Vector;
 import org.slf4j.Logger;
@@ -105,9 +110,27 @@ public class PDFTextStreamEngine extends PDFStreamEngine
         addOperator(new ShowTextLine());
         addOperator(new ShowTextLineAndSpace());
 
+        addOperator(new SetStrokingColorSpace());
+        addOperator(new SetNonStrokingColorSpace());
+        addOperator(new SetGraphicsStateParameters());
+
+        addOperator(new SetStrokingColor());
+        addOperator(new SetStrokingDeviceRGBColor());
+        addOperator(new SetStrokingDeviceCMYKColor());
+        addOperator(new SetStrokingDeviceGrayColor());
+        addOperator(new SetStrokingColorN());
+
+        addOperator(new SetNonStrokingColor());
+        addOperator(new SetNonStrokingDeviceRGBColor());
+        addOperator(new SetNonStrokingDeviceCMYKColor());
+        addOperator(new SetNonStrokingDeviceGrayColor());
+        addOperator(new SetNonStrokingColorN());
+
         // load additional glyph list for Unicode mapping
-        String path = "/org/sejda/sambox/resources/glyphlist/additional.txt";
-        InputStream input = GlyphList.class.getResourceAsStream(path);
+        InputStream input = GlyphList.class
+                .getResourceAsStream("/org/sejda/sambox/resources/glyphlist/additional.txt");
+        requireNotNullArg(input,
+                "Unable to load org/sejda/sambox/resources/glyphlist/additional.txt");
         glyphList = new GlyphList(GlyphList.getAdobeGlyphList(), input);
     }
 
@@ -172,11 +195,11 @@ public class PDFTextStreamEngine extends PDFStreamEngine
             {
                 glyphHeight = capHeight;
             }
-            // PDFBOX-3464, PDFBOX-448:
+            // PDFBOX-3464, PDFBOX-4480, PDFBOX-4553:
             // sometimes even CapHeight has very high value, but Ascent and Descent are ok
             float ascent = fontDescriptor.getAscent();
             float descent = fontDescriptor.getDescent();
-            if (ascent > 0 && descent < 0
+            if (capHeight > ascent && ascent > 0 && descent < 0
                     && ((ascent - descent) / 2 < glyphHeight || Float.compare(glyphHeight, 0) == 0))
             {
                 glyphHeight = (ascent - descent) / 2;
@@ -315,10 +338,19 @@ public class PDFTextStreamEngine extends PDFStreamEngine
             nextX -= cropBox.getLowerLeftX();
             nextY -= cropBox.getLowerLeftY();
         }
+
+        PDColor color = null;
+        RenderingMode renderingMode = state.getTextState().getRenderingMode();
+        if (renderingMode.isFill()) {
+            color = state.getNonStrokingColor();
+        } else if(renderingMode.isStroke()) {
+            color = state.getStrokingColor();
+        }
+        
         processTextPosition(new TextPosition(pageRotation, cropBox.getWidth(), cropBox.getHeight(),
                 translatedTextRenderingMatrix, nextX, nextY, Math.abs(dyDisplay), dxDisplay,
                 Math.abs(spaceWidthDisplay), unicode, new int[] { code }, font, fontSize,
-                (int) (fontSize * textMatrix.getScalingFactorX())));
+                (int) (fontSize * textMatrix.getScalingFactorX()), color, renderingMode));
     }
 
     /**
